﻿using System;
using System.Collections;
using System.Drawing;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;

namespace ChartTest
{
    public partial class Form1 : Form
    {
        private NumericSeries _numericSeries;
        private double _rangeMax;

        public Form1()
        {
            InitializeComponent();
        }

        #region Form1Load
        private void Form1Load(object sender, EventArgs e)
        {
            //  Initialize the Chart
            //
            InitializeChart();


            //  Add Chart text
            //
            AddChartText();


            //  Add chart series objects
            //
            AddNumericSeries(new double[] { 263, 1242 }, "WP #1-1&2 (1505)");
            AddEmptySeries(); //  Empty series (Plotted between the first and second series objects)
            AddNumericSeries(new double[] { 195, 1396 }, "WP #1-3&4 (1591)");
        } 
        #endregion


        #region InitializeChart
        private void InitializeChart()
        {
            //  Specify the chart type
            //
            ultraChart1.ChartType = ChartType.StackColumnChart;
            //
            //  Specify the data range for X and Y axis
            //
            //  (X axis)
            //
            ultraChart1.Axis.X.RangeType = AxisRangeType.Custom;
            ultraChart1.Axis.X.RangeMin = -1;
            ultraChart1.Axis.X.RangeMax = 4;
            //
            //  (Y axis)
            //
            ultraChart1.Axis.Y.RangeType = AxisRangeType.Custom;
            ultraChart1.Axis.Y.RangeMin = 0;
            _rangeMax = ultraChart1.Axis.Y.RangeMax = 1591;


            //  Set the tickmarks with 20% interval on Y axis
            //
            ultraChart1.Axis.Y.TickmarkIntervalType = AxisIntervalType.Ticks;
            ultraChart1.Axis.Y.TickmarkPercentage = 20;
            ultraChart1.Axis.Y.TickmarkStyle = AxisTickStyle.Percentage;


            //  Provide custom label with calculated percent(%) using IRenderLabel interface
            //
            ultraChart1.Axis.Y.Labels.ItemFormatString = "<MY_VALUE>";
            var myLabelHashTable = new Hashtable { { "MY_VALUE", new CustomLabel(_rangeMax) } };
            ultraChart1.LabelHash = myLabelHashTable;


            //  Specify some chart properties and Legend
            //
            ultraChart1.Data.ZeroAligned = true;
            ultraChart1.Axis.X.LineThickness = 0;
            ultraChart1.Axis.Y.LineThickness = 0;


            //  Specify the Chart Legend
            //
            ultraChart1.Legend.Visible = true;
            ultraChart1.Legend.Location = LegendLocation.Bottom;
            ultraChart1.Legend.Margins.Left = 200;
            ultraChart1.Legend.Margins.Top = 0;
            ultraChart1.Legend.BorderThickness = 0;
            ultraChart1.Legend.BackgroundColor = Color.Transparent;
            ultraChart1.Legend.DataAssociation = ChartTypeData.ColumnData;
            ultraChart1.Legend.SpanPercentage = 10;


            //  Set up the Chart Title
            //
            ultraChart1.TitleTop.Text = "Material Cataloguing Process";
            ultraChart1.TitleTop.Font = new Font("Ariel", 12, FontStyle.Bold);
            ultraChart1.TitleTop.HorizontalAlign = StringAlignment.Center;
        } 
        #endregion


        #region AddChartText
        private void AddChartText()
        {
            // Add Chart text (Data value) on the points.
            var displayingValuesAppearance = new ChartTextAppearance();
            var columnChartAppearance = new ColumnChartAppearance();
            displayingValuesAppearance.ChartTextFont = new Font("Arial", 10F);
            displayingValuesAppearance.Column = -2;
            displayingValuesAppearance.ItemFormatString = "<DATA_VALUE:##.##>";
            displayingValuesAppearance.Row = -2;
            displayingValuesAppearance.VerticalAlign = StringAlignment.Center;
            displayingValuesAppearance.Visible = true;
            displayingValuesAppearance.HorizontalAlign = StringAlignment.Center;
            columnChartAppearance.ChartText.Add(displayingValuesAppearance);
            ultraChart1.ColumnChart = columnChartAppearance;
        } 
        #endregion


        #region AddNumericSeries
        private void AddNumericSeries(double[] dataPoints, string seriesLabel)
        {
            double[] dp = dataPoints;
            if (dp.Length < 1)
                return;

            _numericSeries = new NumericSeries { Label = seriesLabel };
            _numericSeries.Points.Add(new NumericDataPoint(dp[0], "Catalogued", false));
            _numericSeries.Points.Add(new NumericDataPoint(dp[1], "Remaining Materials", false));
            ultraChart1.Series.Add(_numericSeries);
        } 
        #endregion


        #region AddEmptySeries
        private void AddEmptySeries()
        {
            var emptySeries = new NumericSeries { Label = "" };
            emptySeries.Points.Add(new NumericDataPoint(0, "", false));
            emptySeries.Points.Add(new NumericDataPoint(0, "", false));
            ultraChart1.Series.Add(emptySeries);
        } 
        #endregion
    }
}
